.. highlight:: python

Machine Learning Algorithms
***************************

Ibmdbpy is a wrapper for machine learning algorithms that are available in dashDB/DB2. Currently, the following machine learning algorithms are available in ibmdbpy: K-means, Naive Bayes, and Association Rules. dashDB/DB2 supports several other data mining algorithms so this list may be extended in the future. This page contains documentation of the machine learning algorithms that are currently available.


.. toctree::
	kmeans.rst
	naive_bayes.rst
	association_rules.rst

